package com.vendor.platform.ui.update;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import com.vendor.platform.core.IToolManager;
import com.vendor.platform.core.PlatformCoreActivator;
import com.vendor.platform.core.ToolDescriptor;
import com.vendor.platform.ui.internal.IniUtils;
import com.vendor.platform.ui.internal.OptionManager;
import java.io.BufferedReader;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.List;
import java.util.Locale;
import org.eclipse.core.runtime.Platform;
import org.eclipse.equinox.p2.metadata.IInstallableUnit;
import org.eclipse.ui.WorkbenchEncoding;

public class UpdateAgent {
  private static final String CFG_FILE = "Updater.ini";
  
  private static final String RES_VER_FILE = "Resources/about me.txt";
  
  private static final String CFG_GROUP = "Options";
  
  private static final String CFG_KEY = "Product";
  
  private static final String SIGN_TAB = "\t";
  
  private static final String SIGN_SPACE = " ";
  
  private static final String SIGN_EMPTY = "";
  
  private static final String RES_VER_HEAD = "version:V";
  
  private static final String RES_VER_CMD = "Resources:";
  
  private static final String SILENT = "/S ";
  
  public static final com.vendor.platform.ui.update.UpdateAgent INSTANCE = new com.vendor.platform.ui.update.UpdateAgent();
  
  private Locale getCurrentLocale() {
    String nl = IniUtils.getIniConfiguration("osgi.nl");
    if (nl.length() == 0)
      nl = Locale.getDefault().toString(); 
    if (nl.equals(Locale.US.toString()))
      return Locale.US; 
    if (nl.equals(Locale.SIMPLIFIED_CHINESE.toString()))
      return Locale.SIMPLIFIED_CHINESE; 
    return Locale.getDefault();
  }
  
  private String getResourceVersion() {
    File resVerFile = new File(Platform.getInstallLocation().getURL().getFile() + "Resources/about me.txt");
    if (!resVerFile.exists())
      return null; 
    BufferedReader reader = null;
    FileInputStream stream = null;
    try {
      stream = new FileInputStream(resVerFile);
      reader = new BufferedReader(new InputStreamReader(stream, WorkbenchEncoding.getWorkbenchDefaultEncoding()));
      String line = null;
      while ((line = reader.readLine()) != null) {
        String lineTrim = line.replace(" ", "").replace("\t", "");
        if (lineTrim.startsWith("version:V"))
          return lineTrim.substring("version:V".length()); 
      } 
    } catch (IOException e) {
      e.printStackTrace();
    } finally {
      if (reader != null)
        try {
          reader.close();
        } catch (IOException e) {
          e.printStackTrace();
        }  
      if (stream != null)
        try {
          stream.close();
        } catch (IOException e) {
          e.printStackTrace();
        }  
    } 
    return null;
  }
  
  public boolean runUpdate(boolean silent) {
    File iniFile = new File(Platform.getInstallLocation().getURL().getFile() + "Updater.ini");
    if (!iniFile.exists())
      return false; 
    OptionManager manager = new OptionManager(iniFile);
    manager.readFile();
    String product = manager.getOption("Options", "Product");
    if (product == null)
      return false; 
    StringBuilder sbCmd = new StringBuilder();
    sbCmd.append("Updater.exe ");
    Locale locale = getCurrentLocale();
    if (locale == Locale.US) {
      sbCmd.append("en ");
    } else if (locale == Locale.SIMPLIFIED_CHINESE) {
      sbCmd.append("cn ");
    } else {
      return false;
    } 
    sbCmd.append("Tool ");
    sbCmd.append(product);
    sbCmd.append(" ");
    if (silent)
      sbCmd.append("/S "); 
    IToolManager toolManager = PlatformCoreActivator.getDefault().getToolManager();
    List<IInstallableUnit> installIUs = PlatformCoreActivator.getDefault().getToolManager().getInstalledToolAndPlatformIUs();
    List<ToolDescriptor> listTools = toolManager.collectFeatureToolsAndPlatform(installIUs);
    for (ToolDescriptor tool : listTools) {
      sbCmd.append(tool.getName());
      sbCmd.append(":");
      sbCmd.append(tool.getVersion());
      sbCmd.append(" ");
    } 
    String resVer = getResourceVersion();
    if (resVer != null) {
      sbCmd.append("Resources:");
      sbCmd.append(resVer);
    } 
    Runtime rt = Runtime.getRuntime();
    try {
      rt.exec(sbCmd.toString());
    } catch (IOException e) {
      return false;
    } 
    return true;
  }
}
